package org.cocos2dx.plugin;

import java.util.ArrayList;
import java.util.Hashtable;

import org.json.JSONObject;

import android.app.Activity;
import android.content.Context;
import android.graphics.Color;
import android.graphics.PixelFormat;
import android.view.Gravity;
import android.view.WindowManager;
import android.widget.RelativeLayout;
import jp.adlantis.android.AdRequestNotifier;
import jp.adlantis.android.AdlantisIconAdSet;
import jp.adlantis.android.AdlantisIconView;
import jp.adlantis.android.AdlantisView;
import jp.adlantis.android.IconAdListener;

public class AdsAdlantisIcon extends AdsAdlantisPlugin{

    private AdlantisIconAdSet iconSet = null;
    private WindowManager mWm = null;
    private static AdsAdlantisIcon mAdapter = null;
    private ArrayList<AdlantisIconView> iconlist = null;
    
    public AdsAdlantisIcon(Context context) {
        super(context);
        mAdapter = this;
    }
    
    @Override
    public void showAds(Hashtable<String, String> adsInfo, int pos) {
        showIconAd();
    }

    private void showIconAd(){
        LogD("showIconAd");
        if(null == iconSet){
            LogD("No icon is added");
        }
        PluginWrapper.runOnMainThread(new Runnable() {
            @Override
            public void run() {
                if (null != iconSet) {
                    iconSet.load();
                }
            }
        });
    }
    
    public void add(final JSONObject iconInfo){
        LogD("add:" + iconInfo.toString());

        PluginWrapper.runOnMainThread(new Runnable() {
            @Override
            public void run() {
                if(null == iconSet){
                    iconSet = new AdlantisIconAdSet(mContext, mPublishID);
                    iconSet.addRequestListener(new AdlantisIconAdListener());
                }
                try{
                    float x = Float.valueOf(iconInfo.getString("x")).floatValue();
                    float y = Float.valueOf(iconInfo.getString("y")).floatValue();
                    boolean showText = iconInfo.getString("showText").equalsIgnoreCase("yes") ? true : false;
                    int textColor = Color.BLACK;
                    if(showText){
                        String textColorStr = iconInfo.getString("textColor");
                        textColor = Color.parseColor(textColorStr);
                    }

                    AdlantisIconView iconView = new AdlantisIconView((Activity) mContext);
                    iconView.setTextColor(textColor);
                    
                    WindowManager.LayoutParams lp = new WindowManager.LayoutParams();
                    lp.width = (int)AdlantisIconView.getIconWidth(mContext);
                    lp.height = (int)(showText ? AdlantisIconView.getTextIconHeight(mContext): AdlantisIconView.getIconHeight(mContext));
                    LogD("x=" + x + ";"+ "y=" + y);
                    lp.x = (int) x;
                    lp.y = (int) y;
                    lp.gravity = Gravity.TOP | Gravity.LEFT;
                    LogD("lp.x=" + lp.x + ";"+ "lp.y=" + lp.y);
                    lp.type = WindowManager.LayoutParams.TYPE_APPLICATION_PANEL;
                    lp.flags |= WindowManager.LayoutParams.FLAG_NOT_FOCUSABLE;
                    lp.format = PixelFormat.TRANSLUCENT;
                    
                    if (null == mWm) {
                        mWm = (WindowManager) mContext.getSystemService("window");
                    }
                    mWm.addView(iconView, lp);
                    iconSet.add(iconView);
                    //use iconlist to store iconView for removing;
                    if(null == iconlist){
                        iconlist = new ArrayList<AdlantisIconView>();
                    }
                    iconlist.add(iconView);
                    
                }catch(Exception e){
                    LogE("icon info error ", e);
                }
            }
        });
        

        
    }

    @Override
    public void hideAds(Hashtable<String, String> adsInfo) {
        PluginWrapper.runOnMainThread(new Runnable() {
            @Override
            public void run() {
                if (null != iconSet) {
                    LogD("hide Ads");
                    
                    //remove iconview from screen
                    if(null != mWm){
                        for( int i = 0; i<iconlist.size(); i++){
                            AdlantisIconView iconView = iconlist.get(i);
                            mWm.removeView(iconView);
                        }
                    }
                    //clear iconlist
                    iconlist.clear();
                    iconlist = null;
                    
                    //clear iconSet
                    iconSet.removeAll();
                    iconSet = null;
                    
                }
            }
        });
    }

    
    private class AdlantisIconAdListener implements IconAdListener{

        @Override
        public void onFailedToReceiveAd(AdRequestNotifier arg0) {
            int errorNo = AdsWrapper.RESULT_CODE_UnknownError;
            String errorMsg = "Unknow error";
            LogD("failed to receive ad : " + errorNo + " , " + errorMsg);
            AdsWrapper.onAdsResult(mAdapter, errorNo, errorMsg);
            
        }

        @Override
        public void onReceiveAd(AdRequestNotifier arg0) {
            LogD("onReceiveAd invoked");
            AdsWrapper.onAdsResult(mAdapter, AdsWrapper.RESULT_CODE_AdsReceived, "Ads request received success!");
            
        }

        @Override
        public void onTouchAd(AdRequestNotifier arg0) {
            // TODO Auto-generated method stub
            
        }

        @Override
        public void onReceiveAd(AdRequestNotifier arg0, int arg1) {
            LogD("onReceiveAd invoked");
            AdsWrapper.onAdsResult(mAdapter, AdsWrapper.RESULT_CODE_AdsReceived, "Ads request received success! count:" + arg1);
            
        }
        
    }
}
